# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_panache_global_optspecs
	string join \n config= stdin-filename= flavor= color= no-color q/quiet v/verbose isolated no-cache cache-dir= j/jobs= h/help V/version
end

function __fish_panache_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_panache_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_panache_using_subcommand
	set -l cmd (__fish_panache_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c panache -n "__fish_panache_needs_command" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_needs_command" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_needs_command" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_needs_command" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_needs_command" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_needs_command" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_needs_command" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_needs_command" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_needs_command" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_needs_command" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_needs_command" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_needs_command" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_needs_command" -s V -l version -d 'Print version'
complete -c panache -n "__fish_panache_needs_command" -f -a "format" -d 'Format a Quarto, Pandoc, or Markdown document'
complete -c panache -n "__fish_panache_needs_command" -f -a "parse" -d 'Parse and display the CST tree for debugging'
complete -c panache -n "__fish_panache_needs_command" -f -a "lsp" -d 'Start the Language Server Protocol server'
complete -c panache -n "__fish_panache_needs_command" -f -a "lint" -d 'Lint a Quarto, Pandoc, or Markdown document'
complete -c panache -n "__fish_panache_needs_command" -f -a "clean" -d 'Delete cache data'
complete -c panache -n "__fish_panache_needs_command" -f -a "debug" -d 'Debug utilities for parser/formatter diagnostics'
complete -c panache -n "__fish_panache_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c panache -n "__fish_panache_using_subcommand format" -l range -d 'Format only lines START:END (e.g., --range 5:10) [Experimental]' -r
complete -c panache -n "__fish_panache_using_subcommand format" -s o -l option -d 'Override an individual config option for this invocation (e.g. -o line-width=100)' -r
complete -c panache -n "__fish_panache_using_subcommand format" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand format" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand format" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand format" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand format" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand format" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand format" -l check -d 'Check if file is formatted (exit code 1 if not)'
complete -c panache -n "__fish_panache_using_subcommand format" -l verify -d '[Deprecated] Verify losslessness and idempotency invariants'
complete -c panache -n "__fish_panache_using_subcommand format" -l force-exclude -d 'Apply exclude patterns to explicitly provided files'
complete -c panache -n "__fish_panache_using_subcommand format" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand format" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand format" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand format" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand format" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand format" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand parse" -l to -d 'Output format: cst (default), pandoc-ast, or pandoc-json' -r -f -a "cst\t''
pandoc-ast\t''
pandoc-json\t''"
complete -c panache -n "__fish_panache_using_subcommand parse" -l json -d 'Write CST JSON output to PATH' -r -F
complete -c panache -n "__fish_panache_using_subcommand parse" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand parse" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand parse" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand parse" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand parse" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand parse" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand parse" -l verify -d '[Deprecated] Verify parser losslessness invariant'
complete -c panache -n "__fish_panache_using_subcommand parse" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand parse" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand parse" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand parse" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand parse" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand parse" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand lsp" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand lsp" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand lsp" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand lsp" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand lsp" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand lsp" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand lsp" -l debug -d 'Enable LSP debug logging to ~/.local/state/panache/lsp-debug.log'
complete -c panache -n "__fish_panache_using_subcommand lsp" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand lsp" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand lsp" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand lsp" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand lsp" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand lsp" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand lint" -l message-format -d 'Diagnostic rendering format' -r -f -a "human\t''
short\t''"
complete -c panache -n "__fish_panache_using_subcommand lint" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand lint" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand lint" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand lint" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand lint" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand lint" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand lint" -l check -d 'Exit with code 1 if violations found (CI mode)'
complete -c panache -n "__fish_panache_using_subcommand lint" -l fix -d 'Automatically fix violations where possible'
complete -c panache -n "__fish_panache_using_subcommand lint" -l force-exclude -d 'Apply exclude patterns to explicitly provided files'
complete -c panache -n "__fish_panache_using_subcommand lint" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand lint" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand lint" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand lint" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand lint" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand lint" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand clean" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand clean" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand clean" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand clean" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand clean" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand clean" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand clean" -l all -d 'Remove all Panache cache buckets'
complete -c panache -n "__fish_panache_using_subcommand clean" -l dry-run -d 'Show what would be removed without deleting anything'
complete -c panache -n "__fish_panache_using_subcommand clean" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand clean" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand clean" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand clean" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand clean" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand clean" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -f -a "format" -d 'Run parser+formatter checks and emit diagnostics'
complete -c panache -n "__fish_panache_using_subcommand debug; and not __fish_seen_subcommand_from format help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l checks -d 'Which checks to run' -r -f -a "idempotency\t''
losslessness\t''
all\t''"
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l dump-dir -d 'Directory where failing artifacts are written' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l config -d 'Path to configuration file' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l stdin-filename -d 'Synthetic filename for stdin input (used for flavor detection)' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l flavor -d 'Override the markdown flavor (overrides config and file extension)' -r -f -a "pandoc\t'Pandoc\'s Markdown (the extended dialect described in `man pandoc`)'
quarto\t'Quarto\'s Markdown (Pandoc-based, with Quarto-specific extensions and shortcodes)'
rmarkdown\t'R Markdown (Pandoc-based, with knitr/Rmd code chunks)'
gfm\t'GitHub Flavored Markdown'
commonmark\t'CommonMark (the strict, standardized base dialect)'
multimarkdown\t'MultiMarkdown (Fletcher Penney\'s extended Markdown dialect)'"
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l color -d 'Control when colored output is used' -r -f -a "auto\t''
always\t''
never\t''"
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l cache-dir -d 'Path to the cache directory (overrides config cache-dir)' -r -F
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -s j -l jobs -d 'Worker threads for multi-file format/lint (0 = auto, 1 = serial)' -r
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l json -d 'Emit JSON output for machine-readable tooling'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l report -d 'Emit Markdown report output suitable for issue descriptions'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l dump-passes -d 'Write input/parse/format pass artifacts to --dump-dir for every file'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l force-exclude -d 'Apply exclude patterns to explicitly provided files'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l no-color -d 'Disable colored output (equivalent to --color never)'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -s q -l quiet -d 'Suppress informational and diagnostic output (errors and primary results still print)'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -s v -l verbose -d 'Print additional informational output where supported'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l isolated -d 'Ignore all discovered configuration files'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -l no-cache -d 'Disable all lint/format cache reads and writes for this run'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from format" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from help" -f -a "format" -d 'Run parser+formatter checks and emit diagnostics'
complete -c panache -n "__fish_panache_using_subcommand debug; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "format" -d 'Format a Quarto, Pandoc, or Markdown document'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "parse" -d 'Parse and display the CST tree for debugging'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "lsp" -d 'Start the Language Server Protocol server'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "lint" -d 'Lint a Quarto, Pandoc, or Markdown document'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "clean" -d 'Delete cache data'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "debug" -d 'Debug utilities for parser/formatter diagnostics'
complete -c panache -n "__fish_panache_using_subcommand help; and not __fish_seen_subcommand_from format parse lsp lint clean debug help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c panache -n "__fish_panache_using_subcommand help; and __fish_seen_subcommand_from debug" -f -a "format" -d 'Run parser+formatter checks and emit diagnostics'
